==> ukui-biometric-auth_3.22.0.0.orig.tar.gz: ukui-biometric-auth-3.22.0.0/bioauth/i18n_ts/bo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>BioAuthWidget</name>
    <message>
        <location filename="../src/bioauthwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.ui" line="146"/>
        <location filename="../src/bioauthwidget.cpp" line="41"/>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="96"/>
        <location filename="../src/bioauthwidget.cpp" line="212"/>
        <source>%1 too many unsuccessful attempts,please enter password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="102"/>
        <source>%1 authentication failure,there are still %2 remaining opportunities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="226"/>
        <source>Please use wechat to scan the code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <location filename="../src/biodevices.cpp" line="64"/>
        <source>Unplugging of %1 device detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="74"/>
        <source>%1 device insertion detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="83"/>
        <source>ukui-biometric-manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="86"/>
        <source>biometric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="457"/>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="459"/>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="461"/>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="463"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="465"/>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="467"/>
        <source>QRCode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <location filename="../src/biodeviceswidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginOptionsWidget</name>
    <message>
        <location filename="../src/loginoptionswidget.cpp" line="59"/>
        <source>Login Options</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ukui-biometric-auth_4.20.0.0.orig.tar.gz: ukui-biometric-auth-4.20.0.0/bioauth/i18n_ts/bo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>BioAuthWidget</name>
    <message>
        <location filename="../src/bioauthwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.ui" line="146"/>
        <location filename="../src/bioauthwidget.cpp" line="41"/>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="96"/>
        <location filename="../src/bioauthwidget.cpp" line="212"/>
        <source>%1 too many unsuccessful attempts,please enter password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="102"/>
        <source>%1 authentication failure,there are still %2 remaining opportunities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/bioauthwidget.cpp" line="226"/>
        <source>Please use wechat to scan the code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <location filename="../src/biodevices.cpp" line="78"/>
        <source>Unplugging of %1 device detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="88"/>
        <source>%1 device insertion detected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="97"/>
        <source>Biometric Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="100"/>
        <source>biometric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="700"/>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="702"/>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="704"/>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="706"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="708"/>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="710"/>
        <source>Ukey</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/biodevices.cpp" line="712"/>
        <source>QRCode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <location filename="../src/biodeviceswidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginOptionsWidget</name>
    <message>
        <location filename="../src/loginoptionswidget.cpp" line="79"/>
        <source>Login Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/loginoptionswidget.cpp" line="320"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
